TemplateContext class

Constructors

TemplateContext({required CleanArchitectConfig config, required NameCases cases, required FeaturePaths paths, required bool skipPresentation})
const

Properties

cases → NameCases
final
config CleanArchitectConfig
final
hashCode int
The hash code for this object.
no setterinherited
paths FeaturePaths
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipPresentation bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited